@@ -9,11 +9,13 @@ __doc__ = r"""
 
 __all__ = []
 
-from draugr.os_utilities.linux_utilities import GtkThemePreferences
+from draugr.os_utilities.linux_utilities.gtk_utilities import GtkThemePreferences
 
 
-def main():
-    """ """
+def main() -> None:
+    """
+    :rtype: None
+    """
     with GtkThemePreferences() as a:
         a.prefer_dark_mode = not a.prefer_dark_mode
 
