@@ -14,10 +14,10 @@ __all__ = ["IgnoreInterruptSignal"]
 
 
 class IgnoreInterruptSignal(contextlib.AbstractContextManager):
-    def __enter__(self):
+    def __enter__(self) -> bool:
         signal.signal(signal.SIGINT, signal.SIG_IGN)
         # signal.getsignal() No sideeffect options for exit
         return True
 
-    def __exit__(self, exc_type, exc_val, exc_tb):
+    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
         signal.signal(signal.SIGINT, signal.SIG_DFL)
