@@ -22,14 +22,8 @@ class GraphWriterMixin(ABC):
     ) -> None:
         """
 
-        :param tag:
-        :type tag:
-        :param data:
-        :type data:
-        :param step:
-        :type step:
-        :param dataformats:
-        :type dataformats:
+            :param model:
+            :param input_to_model:
         :param kwargs:
         :type kwargs:"""
         raise NotImplementedError
