@@ -14,25 +14,28 @@ from collections import Counter, deque
 __all__ = ["Writer", "global_writer", "set_global_writer"]
 
 from itertools import cycle
-from typing import Iterable, Optional
+from typing import Any, Iterable, Optional
 
 from warg import is_none_or_zero_or_negative_or_mod_zero
 from warg import Number, drop_unused_kws
 
 
 class Writer(metaclass=ABCMeta):
-    """"""
+    """ """
 
     @drop_unused_kws
     def __init__(
-        self, *, interval: int = 1, filters: Iterable = None, verbose: bool = False
+        self,
+        *,
+        interval: Optional[int] = 1,
+        filters: Iterable = None,
+        verbose: bool = False
     ):
         """
 
-:param interval:
-:param filters:
-:param verbose:
-"""
+        :param interval:
+        :param filters:
+        :param verbose:"""
         self._counter = Counter()
         self._blip_values = iter(cycle(range(2)))
         self._interval = interval
@@ -42,15 +45,15 @@ class Writer(metaclass=ABCMeta):
     def filter(self, tag: str) -> bool:
         """
 
-    returns a boolean  value, true if to be included, False if to be excluded
+            returns a boolean  value, true if to be included, False if to be excluded
 
-    tag is in filter if not None
-    and within interval for inclusion
+            tag is in filter if not None
+            and within interval for inclusion
 
-:param tag:
-:type tag:
-:return:
-:rtype:"""
+        :param tag:
+        :type tag:
+        :return:
+        :rtype:"""
         is_in_filters = self.filters is None or tag in self.filters
         at_interval = is_none_or_zero_or_negative_or_mod_zero(
             self._interval, self._counter[tag]
@@ -78,12 +81,12 @@ class Writer(metaclass=ABCMeta):
     def scalar(self, tag: str, value: Number, step_i: int = None) -> None:
         """
 
-:param tag:
-:type tag:
-:param value:
-:type value:
-:param step_i:
-:type step_i:"""
+        :param tag:
+        :type tag:
+        :param value:
+        :type value:
+        :param step_i:
+        :type step_i:"""
         if step_i:
             if self.filter(tag):
                 self._scalar(tag, value, self._counter[tag])
@@ -96,10 +99,10 @@ class Writer(metaclass=ABCMeta):
     def blip(self, tag: str, step_i: int = None) -> None:
         """
 
-:param tag:
-:type tag:
-:param step_i:
-:type step_i:"""
+        :param tag:
+        :type tag:
+        :param step_i:
+        :type step_i:"""
         if step_i:
             self.scalar(tag, next(self._blip_values), step_i)
             self.scalar(tag, next(self._blip_values), step_i)
@@ -107,12 +110,12 @@ class Writer(metaclass=ABCMeta):
             self.scalar(tag, next(self._blip_values))
             self.scalar(tag, next(self._blip_values), self._counter[tag])
 
-    def close(self):
-        """"""
+    def close(self) -> Any:
+        """ """
         self._close()
 
-    def open(self):
-        """"""
+    def open(self) -> Any:
+        """ """
         self._open()
 
     @abstractmethod
@@ -127,6 +130,9 @@ class Writer(metaclass=ABCMeta):
     def _open(self):
         return self
 
+    def __call__(self, *args, **kwargs):
+        self.scalar(*args, *kwargs)
+
 
 GLOBAL_WRITER_STACK = deque()
 GLOBAL_WRITER = None
@@ -135,8 +141,8 @@ GLOBAL_WRITER = None
 def global_writer() -> Optional[Writer]:
     """
 
-:return:
-:rtype:"""
+    :return:
+    :rtype:"""
     global GLOBAL_WRITER
     return GLOBAL_WRITER
 
@@ -144,8 +150,8 @@ def global_writer() -> Optional[Writer]:
 def set_global_writer(writer: Writer) -> None:
     """
 
-:return:
-:rtype:"""
+    :return:
+    :rtype:"""
     global GLOBAL_WRITER
     # if GLOBAL_WRITER:
     # GLOBAL_WRITER_STACK TODO: push to stack if existing?
